@@ -781,15 +781,15 @@ onMAinfo <- function(){
          file=system.file( "images", "resolutionimage.gif", package = "RcmdrPlugin.DoE" ) )
     tc <- tklabel(info.window, image="resolution.image")
     tkgrid(tc)
-    catlginfo <- ttklabel(info.window,text="Additional regular designs from this menu:")
-    catlginfo1 <- ttklabel(info.window,text="32 runs (up to 31 factors, res. III), 64 runs (up to 32 factors res. IV, 33 to 63 factors res. III),")
-    catlginfo2 <- ttklabel(info.window,text="128 runs (up to 64 factors, res. IV, 65 to 127 factors, res. III)")
+    #catlginfo <- ttklabel(info.window,text="Additional regular designs from this menu:")
+    #catlginfo1 <- ttklabel(info.window,text="32 runs (up to 31 factors, res. III), 64 runs (up to 32 factors res. IV, 33 to 63 factors res. III),")
+    #catlginfo2 <- ttklabel(info.window,text="128 runs (up to 64 factors, res. IV, 65 to 127 factors, res. III)")
     catlginfo3 <- ttklabel(info.window,text="Additional irregular resolution V designs from general orthogonal arrays menu:")
     catlginfo4 <- ttklabel(info.window,text="128 runs (up to 15 factors), 256 runs (up to 19 factors), 2048 runs (up to 63 factors)")
 
-    tkgrid(catlginfo,sticky="w")
-    tkgrid(catlginfo1)
-    tkgrid(catlginfo2)
+    #tkgrid(catlginfo,sticky="w")
+    #tkgrid(catlginfo1)
+    #tkgrid(catlginfo2)
     tkgrid(catlginfo3, sticky="w")
     tkgrid(catlginfo4)
     
